@@ -3,8 +3,10 @@
 import json
 import urlparse
 
-from amqplib import client_0_8 as amqp
-from amqplib.client_0_8.exceptions import AMQPChannelException
+# from amqplib import client_0_8 as amqp
+# from amqplib.client_0_8.exceptions import AMQPChannelException
+import amqp
+
 import yaml
 
 class MQUriException(BaseException):
@@ -102,7 +104,7 @@ class Producer(object):
         '''called at context mgr loss of scope '''
         try:
             self.close()
-        except amqp.AMQPChannelException:
+        except amqp.ChannelError:
             pass
 
 
@@ -152,11 +154,13 @@ class Consumer(object):
             self.channel.queue_delete(queue=self.queue_name, if_unused=True,
                                       if_empty=True, nowait=True)
             self.channel.close()
-        except AMQPChannelException as emq:
-            if emq.amqp_reply_code not in (404, 406):
+        except amqp.ChannelError as emq:
+            if emq.code not in (404, 406):
                 # 404 - Queue not found
                 # 406 - Queue in use
-                raise
+                pass
+        except:
+            raise
         try:
             self.connection.close()
         except KeyError:
@@ -173,15 +177,13 @@ class Consumer(object):
         """
         self.exchange_name = exchange_name
         try:
+            # assume already declared
+            self.channel.exchange_declare(exchange=self.exchange_name,
+                                          type='', passive=True)
+        except amqp.exceptions.NotFound:
             self.channel.exchange_declare(exchange=self.exchange_name,
                                           type='topic', durable=durable,
                                           auto_delete=auto_delete)
-        except AMQPChannelException:
-            # already declared
-            self.channel.exchange_declare(exchange=self.exchange_name,
-                                          type='topic', durable=durable,
-                                          auto_delete=auto_delete,
-                                          passive=True)
 
     def declare_queue(self, queue_name='', routing_key='', durable=True,
                       exclusive=False, auto_delete=True):
@@ -273,5 +275,5 @@ class Consumer(object):
             # self.channel.queue_delete(queue=self.queue_name, if_unused=True,
             #                           if_empty=True, nowait=True)
             self.close()
-        except amqp.AMQPChannelException:
+        except amqp.ChannelError:
             pass
